"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BasicDecayComponent = void 0;
const BinaryWriter_js_1 = require("../BinaryWriter.js");
const ComponentHash_js_1 = require("../types/ComponentHash.js");
const Component_js_1 = require("./Component.js");
const HUNDRED_YEARS_TICKS = 31557600000000000;
/**
 * @see [Class: `BasicDecayComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/BasicDecayComponent.md)
 * @since v3.0.0
 * @version 3
 *
 * @example
 * import { BasicDecayComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 3;
 * const component = new BasicDecayComponent({ version: componentVersion });
 */
class BasicDecayComponent extends Component_js_1.Component {
    /**
     * @since v3
     *
     * @example
     * import { BasicDecayComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 3;
     * const component = new BasicDecayComponent({ version: componentVersion });
     *
     * const isDisabled = component.isDisabled;
     * // `isDisabled` is `true`
     */
    isDisabled;
    /**
     * @since v3
     *
     * @example
     * import { BasicDecayComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 3;
     * const component = new BasicDecayComponent({ version: componentVersion });
     *
     * const timelineEntry = component.timelineEntry;
     * // `timelineEntry` is `31557600000000000`
     */
    timelineEntry;
    /**
     * @see [Class: `BasicDecayComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/BasicDecayComponent.md)
     * @since v3.0.0
     * @version 3
     *
     * @example
     * import { BasicDecayComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 3;
     * const component = new BasicDecayComponent({ version: componentVersion });
     */
    constructor({ version, isDisabled, timelineEntry }) {
        const hash = ComponentHash_js_1.ComponentHash.BasicDecay;
        const name = 'BasicDecay';
        super({ hash, name, version });
        this.isDisabled = isDisabled ?? true;
        this.timelineEntry = timelineEntry ?? HUNDRED_YEARS_TICKS;
    }
    static fromBinary(reader, version) {
        const props = { version };
        /**
         * @property {boolean} isDisabled
         * @since v3
         */
        if (props.version >= 3) {
            props.isDisabled = reader.readBoolean();
        }
        /**
         * @property {number} timelineEntry
         * @since v3
         */
        if (props.version >= 3) {
            props.timelineEntry = reader.readUnsignedLong();
        }
        return new BasicDecayComponent(props);
    }
    toBinary(version = this.version) {
        const writer = new BinaryWriter_js_1.BinaryWriter();
        /**
         * @property {boolean} isDisabled
         * @since v3
         */
        if (version >= 3) {
            writer.writeBoolean(this.isDisabled);
        }
        /**
         * @property {number} timelineEntry
         * @since v3
         */
        if (version >= 3) {
            writer.writeUnsignedLong(this.timelineEntry);
        }
        return writer.flush();
    }
}
exports.BasicDecayComponent = BasicDecayComponent;
