"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DurabilityModuleComponent = void 0;
const BinaryWriter_js_1 = require("../BinaryWriter.js");
const ComponentHash_js_1 = require("../types/ComponentHash.js");
const Component_js_1 = require("./Component.js");
/**
 * @see [Class: `DurabilityModuleComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/DurabilityModuleComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { DurabilityModuleComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new DurabilityModuleComponent({ version: componentVersion });
 */
class DurabilityModuleComponent extends Component_js_1.Component {
    /**
     * The integrity of the prefab this component is attached to.
     *
     * @since v1
     *
     * @example
     * import { DurabilityModuleComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new DurabilityModuleComponent({ version: componentVersion });
     *
     * const integrity = component.integrity;
     * // `integrity` is `1`
     */
    integrity;
    /**
     * @see [Class: `DurabilityModuleComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/DurabilityModuleComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { DurabilityModuleComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new DurabilityModuleComponent({ version: componentVersion });
     */
    constructor({ version, integrity }) {
        const hash = ComponentHash_js_1.ComponentHash.DurabilityModule;
        const name = 'DurabilityModule';
        super({ hash, name, version });
        this.integrity = integrity ?? 1;
    }
    static fromBinary(reader, version) {
        const props = { version };
        /**
         * @property {float} integrity
         * @since v1
         */
        if (props.version >= 1) {
            props.integrity = reader.readFloat();
        }
        return new DurabilityModuleComponent(props);
    }
    toBinary(version = this.version) {
        const writer = new BinaryWriter_js_1.BinaryWriter();
        /**
         * @property {float} integrity
         * @since v1
         */
        if (version >= 1) {
            writer.writeFloat(this.integrity);
        }
        return writer.flush();
    }
}
exports.DurabilityModuleComponent = DurabilityModuleComponent;
