"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FireComponent = void 0;
const BinaryWriter_js_1 = require("../BinaryWriter.js");
const ComponentHash_js_1 = require("../types/ComponentHash.js");
const Component_js_1 = require("./Component.js");
/**
 * @see [Class: `FireComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/FireComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { FireComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new FireComponent({ version: componentVersion });
 */
class FireComponent extends Component_js_1.Component {
    /**
     * The progress of the consumption of fuel attached to this component's prefab.
     *
     * @since v1
     *
     * @example
     * import { FireComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new FireComponent({ version: componentVersion });
     *
     * const fuelConsumptionProgress = component.fuelConsumptionProgress;
     * // `fuelConsumptionProgress` is `1`
     */
    fuelConsumptionProgress;
    /**
     * @see [Class: `FireComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/FireComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { FireComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new FireComponent({ version: componentVersion });
     */
    constructor({ version, fuelConsumptionProgress }) {
        const hash = ComponentHash_js_1.ComponentHash.Fire;
        const name = 'Fire';
        super({ hash, name, version });
        this.fuelConsumptionProgress = fuelConsumptionProgress ?? 1;
    }
    static fromBinary(reader, version) {
        const props = { version };
        /**
         * @property {float} fuelConsumptionProgress
         * @since v1
         */
        if (props.version >= 1) {
            props.fuelConsumptionProgress = reader.readFloat();
        }
        return new FireComponent(props);
    }
    toBinary(version = this.version) {
        const writer = new BinaryWriter_js_1.BinaryWriter();
        /**
         * @property {float} fuelConsumptionProgress
         * @since v1
         */
        if (version >= 1) {
            writer.writeFloat(this.fuelConsumptionProgress);
        }
        return writer.flush();
    }
}
exports.FireComponent = FireComponent;
