"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogicBoolSenderComponent = void 0;
const BinaryWriter_js_1 = require("../BinaryWriter.js");
const ComponentHash_js_1 = require("../types/ComponentHash.js");
const Component_js_1 = require("./Component.js");
/**
 * @see [Class: `LogicBoolSenderComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicBoolSenderComponent.md)
 * @since v3.0.0
 * @version 2
 *
 * @example
 * import { LogicBoolSenderComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 2;
 * const component = new LogicBoolSenderComponent({ version: componentVersion });
 */
class LogicBoolSenderComponent extends Component_js_1.Component {
    /**
     * We're not quite sure what this property does.
     *
     * @since v2
     *
     * @example
     * import { LogicBoolSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new LogicBoolSenderComponent({ version: componentVersion });
     *
     * const updatedValue = component.updatedValue;
     * // `updatedValue` is `3171294583`
     */
    updatedValue;
    /**
     * We're not quite sure what this property does.
     *
     * @since v2
     *
     * @example
     * import { LogicBoolSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new LogicBoolSenderComponent({ version: componentVersion });
     *
     * const changedExternally = component.changedExternally;
     * // `changedExternally` is `32`
     */
    changedExternally;
    /**
     * The identifier of this `LogicBoolSender` that a `LogicBoolReceiver` connects to.
     *
     * @since v2
     *
     * @example
     * import { LogicBoolSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new LogicBoolSenderComponent({ version: componentVersion });
     *
     * const identifier = component.identifier;
     * // `identifier` is `0`
     */
    identifier;
    /**
     * The output value of this `LogicBoolSender` that a `LogicBoolReceiver` reads as its input.
     *
     * @since v2
     *
     * @example
     * import { LogicBoolSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new LogicBoolSenderComponent({ version: componentVersion });
     *
     * const value = component.value;
     * // `value` is `false`
     */
    value;
    /**
     * @see [Class: `LogicBoolSenderComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicBoolSenderComponent.md)
     * @since v3.0.0
     * @version 2
     *
     * @example
     * import { LogicBoolSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new LogicBoolSenderComponent({ version: componentVersion });
     */
    constructor({ version, updatedValue, changedExternally, identifier, value }) {
        const hash = ComponentHash_js_1.ComponentHash.LogicBoolSender;
        const name = 'LogicBoolSender';
        super({ hash, name, version });
        this.updatedValue = updatedValue ?? 3171294583;
        this.changedExternally = changedExternally ?? 32;
        this.identifier = identifier ?? 0;
        this.value = value ?? false;
    }
    static fromBinary(reader, version) {
        const props = { version };
        /**
         * @property {number} updatedValue
         * @since v2
         */
        if (props.version >= 2) {
            props.updatedValue = reader.readUnsignedInteger();
        }
        /**
         * @property {number} changedExternally
         * @since v2
         */
        if (props.version >= 2) {
            props.changedExternally = reader.readUnsignedInteger();
        }
        /**
         * @property {number} identifier
         * @since v2
         */
        if (props.version >= 2) {
            props.identifier = reader.readUnsignedInteger();
        }
        /**
         * @property {boolean} value
         * @since v2
         */
        if (props.version >= 2) {
            props.value = reader.readBoolean();
        }
        return new LogicBoolSenderComponent(props);
    }
    toBinary(version = this.version) {
        const writer = new BinaryWriter_js_1.BinaryWriter();
        /**
         * @property {number} updatedValue
         * @since v2
         */
        if (version >= 2) {
            writer.writeUnsignedInteger(this.updatedValue);
        }
        /**
         * @property {number} changedExternally
         * @since v2
         */
        if (version >= 2) {
            writer.writeUnsignedInteger(this.changedExternally);
        }
        /**
         * @property {number} identifier
         * @since v2
         */
        if (version >= 2) {
            writer.writeUnsignedInteger(this.identifier);
        }
        /**
         * @property {boolean} value
         * @since v2
         */
        if (version >= 2) {
            writer.writeBoolean(this.value);
        }
        return writer.flush();
    }
}
exports.LogicBoolSenderComponent = LogicBoolSenderComponent;
