"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogicIntReceiverComponent = void 0;
const BinaryWriter_js_1 = require("../BinaryWriter.js");
const ComponentHash_js_1 = require("../types/ComponentHash.js");
const Component_js_1 = require("./Component.js");
/**
 * @see [Class: `LogicIntReceiverComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicIntReceiverComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { LogicIntReceiverComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new LogicIntReceiverComponent({ version: componentVersion });
 */
class LogicIntReceiverComponent extends Component_js_1.Component {
    /**
     * The identifier of the `LogicIntSender` that is connected to this `LogicIntReceiver`.
     *
     * @since v1
     *
     * @example
     * import { LogicIntReceiverComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicIntReceiverComponent({ version: componentVersion });
     *
     * const sender = component.sender;
     * // `sender` is `0`
     */
    sender;
    /**
     * @see [Class: `LogicIntReceiverComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicIntReceiverComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { LogicIntReceiverComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicIntReceiverComponent({ version: componentVersion });
     */
    constructor({ version, sender }) {
        const hash = ComponentHash_js_1.ComponentHash.LogicIntReceiver;
        const name = 'LogicIntReceiver';
        super({ hash, name, version });
        this.sender = sender ?? 0;
    }
    static fromBinary(reader, version) {
        const props = { version };
        /**
         * @property {number} sender
         * @since v1
         */
        if (props.version >= 1) {
            props.sender = reader.readUnsignedInteger();
        }
        return new LogicIntReceiverComponent(props);
    }
    toBinary(version = this.version) {
        const writer = new BinaryWriter_js_1.BinaryWriter();
        /**
         * @property {number} sender
         * @since v1
         */
        if (version >= 1) {
            writer.writeUnsignedInteger(this.sender);
        }
        return writer.flush();
    }
}
exports.LogicIntReceiverComponent = LogicIntReceiverComponent;
