"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readChildren = void 0;
const Prefab_js_1 = require("../Prefab.js");
/**
 * Reads all child prefabs from the given `BinaryReader` and returns an array of `PrefabChild`.
 *
 * @example
 * import { BinaryReader, readChildren } from 'att-string-transcoder';
 *
 * const reader = new BinaryReader('...');
 *
 * const componentVersions = new Map<number, number>([
 *   [ComponentHash.NetworkRigidbody, 1],
 *   [ComponentHash.PhysicalMaterialPart, 1],
 *   [ComponentHash.Pickup, 2]
 *   // etc...
 * ]);
 *
 * const children = readChildren(reader, componentVersions);
 */
function readChildren(reader, componentVersions) {
    const children = [];
    const isLooping = true;
    while (isLooping) {
        const hasChild = reader.readBoolean();
        if (!hasChild)
            break;
        const parentHash = reader.readUnsignedInteger();
        const prefab = Prefab_js_1.Prefab.fromBinary(reader, componentVersions);
        children.push({ parentHash, prefab });
    }
    return children;
}
exports.readChildren = readChildren;
