"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readComponent = void 0;
const UnsupportedComponent_js_1 = require("../components/UnsupportedComponent.js");
const supportedComponents_js_1 = require("../supportedComponents.js");
/**
 * Reads next component from the given `BinaryReader` and returns a `Component` instance.
 *
 * @example
 * import { BinaryReader, readChildren } from 'att-string-transcoder';
 *
 * const reader = new BinaryReader('...');
 * const hash = 2290978823;
 * const name = 'NetworkRigidbody';
 * const version = 1;
 *
 * const component = readComponent(reader, hash, name, version);
 */
function readComponent(reader, hash, name, version) {
    /* Get the component's data length. */
    const dataLength = reader.readUnsignedInteger();
    /* Get the component's class. */
    const SupportedComponent = supportedComponents_js_1.supportedComponents[name];
    /* Create a component instance from the binary data string. */
    if (typeof SupportedComponent === 'undefined') {
        return UnsupportedComponent_js_1.UnsupportedComponent.fromBinary(reader, version, hash, name, dataLength);
    }
    else {
        return SupportedComponent.fromBinary(reader, version);
    }
}
exports.readComponent = readComponent;
