import { BinaryWriter } from '../BinaryWriter.js';
import { ComponentHash } from '../types/ComponentHash.js';
import { Component } from './Component.js';
/**
 * @see [Class: `DoorComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/DoorComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { DoorComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new DoorComponent({ version: componentVersion });
 */
export class DoorComponent extends Component {
    /**
     * Reveals the open state of this component's prefab.
     *
     * @since v1
     *
     * @example
     * import { DoorComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new DoorComponent({ version: componentVersion });
     *
     * const isOpen = component.isOpen;
     * // `isOpen` is `false`
     */
    isOpen;
    /**
     * @see [Class: `DoorComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/DoorComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { DoorComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new DoorComponent({ version: componentVersion });
     */
    constructor({ version, isOpen }) {
        const hash = ComponentHash.Door;
        const name = 'Door';
        super({ hash, name, version });
        this.isOpen = isOpen ?? false;
    }
    static fromBinary(reader, version) {
        const props = { version };
        /**
         * @property {boolean} isOpen
         * @since v1
         */
        if (props.version >= 1) {
            props.isOpen = reader.readBoolean();
        }
        return new DoorComponent(props);
    }
    toBinary(version = this.version) {
        const writer = new BinaryWriter();
        /**
         * @property {boolean} isOpen
         * @since v1
         */
        if (version >= 1) {
            writer.writeBoolean(this.isOpen);
        }
        return writer.flush();
    }
}
