import { BinaryWriter } from '../BinaryWriter.js';
import { ComponentHash } from '../types/ComponentHash.js';
import { Component } from './Component.js';
/**
 * @see [Class: `LogicIntSenderComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicIntSenderComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { LogicIntSenderComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new LogicIntSenderComponent({ version: componentVersion });
 */
export class LogicIntSenderComponent extends Component {
    /**
     * We're not quite sure what this property does.
     *
     * @since v1
     *
     * @example
     * import { LogicIntSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicIntSenderComponent({ version: componentVersion });
     *
     * const updatedValue = component.updatedValue;
     * // `updatedValue` is `3171294583`
     */
    updatedValue;
    /**
     * We're not quite sure what this property does.
     *
     * @since v1
     *
     * @example
     * import { LogicIntSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicIntSenderComponent({ version: componentVersion });
     *
     * const changedExternally = component.changedExternally;
     * // `changedExternally` is `32`
     */
    changedExternally;
    /**
     * The identifier of this `LogicIntSender` that a `LogicIntReceiver` connects to.
     *
     * @since v1
     *
     * @example
     * import { LogicIntSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicIntSenderComponent({ version: componentVersion });
     *
     * const identifier = component.identifier;
     * // `identifier` is `0`
     */
    identifier;
    /**
     * The output value of this `LogicIntSender` that a `LogicIntReceiver` reads as its input.
     *
     * @since v1
     *
     * @example
     * import { LogicIntSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicIntSenderComponent({ version: componentVersion });
     *
     * const value = component.value;
     * // `value` is `0`
     */
    value;
    /**
     * @see [Class: `LogicIntSenderComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicIntSenderComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { LogicIntSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicIntSenderComponent({ version: componentVersion });
     */
    constructor({ version, updatedValue, changedExternally, identifier, value }) {
        const hash = ComponentHash.LogicIntSender;
        const name = 'LogicIntSender';
        super({ hash, name, version });
        this.updatedValue = updatedValue ?? 3171294583;
        this.changedExternally = changedExternally ?? 32;
        this.identifier = identifier ?? 0;
        this.value = value ?? 0;
    }
    static fromBinary(reader, version) {
        const props = { version };
        /**
         * @property {number} updatedValue
         * @since v1
         */
        if (props.version >= 1) {
            props.updatedValue = reader.readUnsignedInteger();
        }
        /**
         * @property {number} changedExternally
         * @since v1
         */
        if (props.version >= 1) {
            props.changedExternally = reader.readUnsignedInteger();
        }
        /**
         * @property {number} identifier
         * @since v1
         */
        if (props.version >= 1) {
            props.identifier = reader.readUnsignedInteger();
        }
        /**
         * @property {number} value
         * @since v1
         */
        if (props.version >= 1) {
            props.value = reader.readSignedInteger();
        }
        return new LogicIntSenderComponent(props);
    }
    toBinary(version = this.version) {
        const writer = new BinaryWriter();
        /**
         * @property {number} updatedValue
         * @since v1
         */
        if (version >= 1) {
            writer.writeUnsignedInteger(this.updatedValue);
        }
        /**
         * @property {number} changedExternally
         * @since v1
         */
        if (version >= 1) {
            writer.writeUnsignedInteger(this.changedExternally);
        }
        /**
         * @property {number} identifier
         * @since v1
         */
        if (version >= 1) {
            writer.writeUnsignedInteger(this.identifier);
        }
        /**
         * @property {number} value
         * @since v1
         */
        if (version >= 1) {
            writer.writeSignedInteger(this.value);
        }
        return writer.flush();
    }
}
