import { BinaryWriter } from '../BinaryWriter.js';
import { ComponentHash } from '../types/ComponentHash.js';
import { Component } from './Component.js';
/**
 * @see [Class: `LogicVector3ReceiverComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicVector3ReceiverComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { LogicVector3ReceiverComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new LogicVector3ReceiverComponent({ version: componentVersion });
 */
export class LogicVector3ReceiverComponent extends Component {
    /**
     * The identifier of the `LogicVector3Sender` that is connected to this `LogicVector3Receiver`.
     *
     * @since v1
     *
     * @example
     * import { LogicVector3ReceiverComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicVector3ReceiverComponent({ version: componentVersion });
     *
     * const sender = component.sender;
     * // `sender` is `0`
     */
    sender;
    /**
     * @see [Class: `LogicVector3ReceiverComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicVector3ReceiverComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { LogicVector3ReceiverComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicVector3ReceiverComponent({ version: componentVersion });
     */
    constructor({ version, sender }) {
        const hash = ComponentHash.LogicVector3Receiver;
        const name = 'LogicVector3Receiver';
        super({ hash, name, version });
        this.sender = sender ?? 0;
    }
    static fromBinary(reader, version) {
        const props = { version };
        /**
         * @property {number} sender
         * @since v1
         */
        if (props.version >= 1) {
            props.sender = reader.readUnsignedInteger();
        }
        return new LogicVector3ReceiverComponent(props);
    }
    toBinary(version = this.version) {
        const writer = new BinaryWriter();
        /**
         * @property {number} sender
         * @since v1
         */
        if (version >= 1) {
            writer.writeUnsignedInteger(this.sender);
        }
        return writer.flush();
    }
}
