import type { BinaryReader } from '../BinaryReader.js';
import type { BinaryString } from '../types/BinaryString.js';
import { Component, type ComponentProps } from './Component.js';
type BasicDecayComponentPropsV3 = {
    isDisabled?: boolean | undefined;
    timelineEntry?: number | undefined;
};
export type BasicDecayComponentProps = BasicDecayComponentPropsV3;
/**
 * @see [Class: `BasicDecayComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/BasicDecayComponent.md)
 * @since v3.0.0
 * @version 3
 *
 * @example
 * import { BasicDecayComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 3;
 * const component = new BasicDecayComponent({ version: componentVersion });
 */
export declare class BasicDecayComponent extends Component {
    /**
     * @since v3
     *
     * @example
     * import { BasicDecayComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 3;
     * const component = new BasicDecayComponent({ version: componentVersion });
     *
     * const isDisabled = component.isDisabled;
     * // `isDisabled` is `true`
     */
    isDisabled: boolean;
    /**
     * @since v3
     *
     * @example
     * import { BasicDecayComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 3;
     * const component = new BasicDecayComponent({ version: componentVersion });
     *
     * const timelineEntry = component.timelineEntry;
     * // `timelineEntry` is `31557600000000000`
     */
    timelineEntry: number;
    /**
     * @see [Class: `BasicDecayComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/BasicDecayComponent.md)
     * @since v3.0.0
     * @version 3
     *
     * @example
     * import { BasicDecayComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 3;
     * const component = new BasicDecayComponent({ version: componentVersion });
     */
    constructor({ version, isDisabled, timelineEntry }: ComponentProps & BasicDecayComponentProps);
    static fromBinary(reader: BinaryReader, version: number): BasicDecayComponent;
    toBinary(version?: number): BinaryString;
}
export {};
