import type { BinaryReader } from '../BinaryReader.js';
import type { BinaryString } from '../types/BinaryString.js';
import { Component, type ComponentProps } from './Component.js';
type DurabilityModuleComponentPropsV1 = {
    integrity?: number | undefined;
};
export type DurabilityModuleComponentProps = DurabilityModuleComponentPropsV1;
/**
 * @see [Class: `DurabilityModuleComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/DurabilityModuleComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { DurabilityModuleComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new DurabilityModuleComponent({ version: componentVersion });
 */
export declare class DurabilityModuleComponent extends Component {
    /**
     * The integrity of the prefab this component is attached to.
     *
     * @since v1
     *
     * @example
     * import { DurabilityModuleComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new DurabilityModuleComponent({ version: componentVersion });
     *
     * const integrity = component.integrity;
     * // `integrity` is `1`
     */
    integrity: number;
    /**
     * @see [Class: `DurabilityModuleComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/DurabilityModuleComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { DurabilityModuleComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new DurabilityModuleComponent({ version: componentVersion });
     */
    constructor({ version, integrity }: ComponentProps & DurabilityModuleComponentProps);
    static fromBinary(reader: BinaryReader, version: number): DurabilityModuleComponent;
    toBinary(version?: number): BinaryString;
}
export {};
