import type { BinaryReader } from '../BinaryReader.js';
import type { BinaryString } from '../types/BinaryString.js';
import { Component, type ComponentProps } from './Component.js';
type FuseComponentPropsV1 = {
    isFinished?: boolean | undefined;
    isLit?: boolean | undefined;
    currentFuseAmount?: number | undefined;
};
export type FuseComponentProps = FuseComponentPropsV1;
/**
 * @see [Class: `FuseComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/FuseComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { FuseComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new FuseComponent({ version: componentVersion });
 */
export declare class FuseComponent extends Component {
    /**
     * Whether the fuse is finished or not.
     *
     * @since v1
     *
     * @example
     * import { FuseComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new FuseComponent({ version: componentVersion });
     *
     * const isFinished = component.isFinished;
     * // `isFinished` is `false`
     */
    isFinished: boolean;
    /**
     * Whether the fuse is lit or not.
     *
     * @since v1
     *
     * @example
     * import { FuseComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new FuseComponent({ version: componentVersion });
     *
     * const isLit = component.isLit;
     * // `isLit` is `false`
     */
    isLit: boolean;
    /**
     * How much of the fuse is left.
     *
     * @since v1
     *
     * @example
     * import { FuseComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new FuseComponent({ version: componentVersion });
     *
     * const currentFuseAmount = component.currentFuseAmount;
     * // `currentFuseAmount` is `1`
     */
    currentFuseAmount: number;
    /**
     * @see [Class: `FuseComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/FuseComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { FuseComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new FuseComponent({ version: componentVersion });
     */
    constructor({ version, isFinished, isLit, currentFuseAmount }: ComponentProps & FuseComponentProps);
    static fromBinary(reader: BinaryReader, version: number): FuseComponent;
    toBinary(version?: number): BinaryString;
}
export {};
