import type { BinaryReader } from '../BinaryReader.js';
import type { BinaryString } from '../types/BinaryString.js';
import { Component, type ComponentProps } from './Component.js';
type HeatSourceBaseComponentPropsV1 = {
    isLit?: boolean | undefined;
    progress?: number | undefined;
    time?: number | undefined;
};
export type HeatSourceBaseComponentProps = HeatSourceBaseComponentPropsV1;
/**
 * @see [Class: `HeatSourceBaseComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/HeatSourceBaseComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { HeatSourceBaseComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new HeatSourceBaseComponent({ version: componentVersion });
 */
export declare class HeatSourceBaseComponent extends Component {
    /**
     * Whether this heat source is lit and active or not.
     *
     * @since v1
     *
     * @example
     * import { HeatSourceBaseComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new HeatSourceBaseComponent({ version: componentVersion });
     *
     * const isLit = component.isLit;
     */
    isLit: boolean;
    /**
     * Progress of the heat source until extinguishing.
     *
     * @since v1
     *
     * @example
     * import { HeatSourceBaseComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new HeatSourceBaseComponent({ version: componentVersion });
     *
     * const progress = component.progress;
     * // `progress` is `0`
     */
    progress: number;
    /**
     * @since v1
     *
     * @example
     * import { HeatSourceBaseComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new HeatSourceBaseComponent({ version: componentVersion });
     *
     * const time = component.time;
     * // `time` is `31557600000000000`
     */
    time: number;
    /**
     * @see [Class: `HeatSourceBaseComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/HeatSourceBaseComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { HeatSourceBaseComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new HeatSourceBaseComponent({ version: componentVersion });
     */
    constructor({ version, isLit, progress, time }: ComponentProps & HeatSourceBaseComponentProps);
    static fromBinary(reader: BinaryReader, version: number): HeatSourceBaseComponent;
    toBinary(version?: number): BinaryString;
}
export {};
