import type { BinaryReader } from '../BinaryReader.js';
import type { BinaryString } from '../types/BinaryString.js';
import { Component, type ComponentProps } from './Component.js';
type LogicBoolSenderComponentPropsV2 = {
    updatedValue?: number | undefined;
    changedExternally?: number | undefined;
    identifier?: number | undefined;
    value?: boolean | undefined;
};
export type LogicBoolSenderComponentProps = LogicBoolSenderComponentPropsV2;
/**
 * @see [Class: `LogicBoolSenderComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicBoolSenderComponent.md)
 * @since v3.0.0
 * @version 2
 *
 * @example
 * import { LogicBoolSenderComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 2;
 * const component = new LogicBoolSenderComponent({ version: componentVersion });
 */
export declare class LogicBoolSenderComponent extends Component {
    /**
     * We're not quite sure what this property does.
     *
     * @since v2
     *
     * @example
     * import { LogicBoolSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new LogicBoolSenderComponent({ version: componentVersion });
     *
     * const updatedValue = component.updatedValue;
     * // `updatedValue` is `3171294583`
     */
    updatedValue: number;
    /**
     * We're not quite sure what this property does.
     *
     * @since v2
     *
     * @example
     * import { LogicBoolSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new LogicBoolSenderComponent({ version: componentVersion });
     *
     * const changedExternally = component.changedExternally;
     * // `changedExternally` is `32`
     */
    changedExternally: number;
    /**
     * The identifier of this `LogicBoolSender` that a `LogicBoolReceiver` connects to.
     *
     * @since v2
     *
     * @example
     * import { LogicBoolSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new LogicBoolSenderComponent({ version: componentVersion });
     *
     * const identifier = component.identifier;
     * // `identifier` is `0`
     */
    identifier: number;
    /**
     * The output value of this `LogicBoolSender` that a `LogicBoolReceiver` reads as its input.
     *
     * @since v2
     *
     * @example
     * import { LogicBoolSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new LogicBoolSenderComponent({ version: componentVersion });
     *
     * const value = component.value;
     * // `value` is `false`
     */
    value: boolean;
    /**
     * @see [Class: `LogicBoolSenderComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicBoolSenderComponent.md)
     * @since v3.0.0
     * @version 2
     *
     * @example
     * import { LogicBoolSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new LogicBoolSenderComponent({ version: componentVersion });
     */
    constructor({ version, updatedValue, changedExternally, identifier, value }: ComponentProps & LogicBoolSenderComponentProps);
    static fromBinary(reader: BinaryReader, version: number): LogicBoolSenderComponent;
    toBinary(version?: number): BinaryString;
}
export {};
