import type { BinaryReader } from '../BinaryReader.js';
import type { BinaryString } from '../types/BinaryString.js';
import { Component, type ComponentProps } from './Component.js';
type LogicFloatReceiverComponentPropsV1 = {
    sender?: number | undefined;
};
export type LogicFloatReceiverComponentProps = LogicFloatReceiverComponentPropsV1;
/**
 * @see [Class: `LogicFloatReceiverComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicFloatReceiverComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { LogicFloatReceiverComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new LogicFloatReceiverComponent({ version: componentVersion });
 */
export declare class LogicFloatReceiverComponent extends Component {
    /**
     * The identifier of the `LogicFloatSender` that is connected to this `LogicFloatReceiver`.
     *
     * @since v1
     *
     * @example
     * import { LogicFloatReceiverComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicFloatReceiverComponent({ version: componentVersion });
     *
     * const sender = component.sender;
     * // `sender` is `0`
     */
    sender: number;
    /**
     * @see [Class: `LogicFloatReceiverComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicFloatReceiverComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { LogicFloatReceiverComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicFloatReceiverComponent({ version: componentVersion });
     */
    constructor({ version, sender }: ComponentProps & LogicFloatReceiverComponentProps);
    static fromBinary(reader: BinaryReader, version: number): LogicFloatReceiverComponent;
    toBinary(version?: number): BinaryString;
}
export {};
