import type { BinaryReader } from '../BinaryReader.js';
import type { BinaryString } from '../types/BinaryString.js';
import { Component, type ComponentProps } from './Component.js';
type LogicFloatSenderComponentPropsV1 = {
    updatedValue?: number | undefined;
    changedExternally?: number | undefined;
    identifier?: number | undefined;
    value?: number | undefined;
};
export type LogicFloatSenderComponentProps = LogicFloatSenderComponentPropsV1;
/**
 * @see [Class: `LogicFloatSenderComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicFloatSenderComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { LogicFloatSenderComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new LogicFloatSenderComponent({ version: componentVersion });
 */
export declare class LogicFloatSenderComponent extends Component {
    /**
     * We're not quite sure what this property does.
     *
     * @since v1
     *
     * @example
     * import { LogicFloatSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicFloatSenderComponent({ version: componentVersion });
     *
     * const updatedValue = component.updatedValue;
     * // `updatedValue` is `3171294583`
     */
    updatedValue: number;
    /**
     * We're not quite sure what this property does.
     *
     * @since v1
     *
     * @example
     * import { LogicFloatSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicFloatSenderComponent({ version: componentVersion });
     *
     * const changedExternally = component.changedExternally;
     * // `changedExternally` is `32`
     */
    changedExternally: number;
    /**
     * The identifier of this `LogicFloatSender` that a `LogicFloatReceiver` connects to.
     *
     * @since v1
     *
     * @example
     * import { LogicFloatSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicFloatSenderComponent({ version: componentVersion });
     *
     * const identifier = component.identifier;
     * // `identifier` is `0`
     */
    identifier: number;
    /**
     * The output value of this `LogicFloatSender` that a `LogicFloatReceiver` reads as its input.
     *
     * @since v1
     *
     * @example
     * import { LogicFloatSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicFloatSenderComponent({ version: componentVersion });
     *
     * const value = component.value;
     * // `value` is `0`
     */
    value: number;
    /**
     * @see [Class: `LogicFloatSenderComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicFloatSenderComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { LogicFloatSenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicFloatSenderComponent({ version: componentVersion });
     */
    constructor({ version, updatedValue, changedExternally, identifier, value }: ComponentProps & LogicFloatSenderComponentProps);
    static fromBinary(reader: BinaryReader, version: number): LogicFloatSenderComponent;
    toBinary(version?: number): BinaryString;
}
export {};
