import type { BinaryReader } from '../BinaryReader.js';
import type { BinaryString } from '../types/BinaryString.js';
import { Component, type ComponentProps } from './Component.js';
type LogicIntReceiverComponentPropsV1 = {
    sender?: number | undefined;
};
export type LogicIntReceiverComponentProps = LogicIntReceiverComponentPropsV1;
/**
 * @see [Class: `LogicIntReceiverComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicIntReceiverComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { LogicIntReceiverComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new LogicIntReceiverComponent({ version: componentVersion });
 */
export declare class LogicIntReceiverComponent extends Component {
    /**
     * The identifier of the `LogicIntSender` that is connected to this `LogicIntReceiver`.
     *
     * @since v1
     *
     * @example
     * import { LogicIntReceiverComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicIntReceiverComponent({ version: componentVersion });
     *
     * const sender = component.sender;
     * // `sender` is `0`
     */
    sender: number;
    /**
     * @see [Class: `LogicIntReceiverComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicIntReceiverComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { LogicIntReceiverComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicIntReceiverComponent({ version: componentVersion });
     */
    constructor({ version, sender }: ComponentProps & LogicIntReceiverComponentProps);
    static fromBinary(reader: BinaryReader, version: number): LogicIntReceiverComponent;
    toBinary(version?: number): BinaryString;
}
export {};
