import type { BinaryReader } from '../BinaryReader.js';
import type { BinaryString } from '../types/BinaryString.js';
import { Component, type ComponentProps } from './Component.js';
type Vector3 = {
    x: number;
    y: number;
    z: number;
};
type LogicVector3SenderComponentPropsV1 = {
    updatedValue?: number | undefined;
    changedExternally?: number | undefined;
    identifier?: number | undefined;
    value?: Vector3 | undefined;
};
export type LogicVector3SenderComponentProps = LogicVector3SenderComponentPropsV1;
/**
 * @see [Class: `LogicVector3SenderComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicVector3SenderComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { LogicVector3SenderComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new LogicVector3SenderComponent({ version: componentVersion });
 */
export declare class LogicVector3SenderComponent extends Component {
    /**
     * We're not quite sure what this property does.
     *
     * @since v1
     *
     * @example
     * import { LogicVector3SenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicVector3SenderComponent({ version: componentVersion });
     *
     * const updatedValue = component.updatedValue;
     * // `updatedValue` is `3171294583`
     */
    updatedValue: number;
    /**
     * We're not quite sure what this property does.
     *
     * @since v1
     *
     * @example
     * import { LogicVector3SenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicVector3SenderComponent({ version: componentVersion });
     *
     * const changedExternally = component.changedExternally;
     * // `changedExternally` is `32`
     */
    changedExternally: number;
    /**
     * The identifier of this `LogicVector3Sender` that a `LogicVector3Receiver` connects to.
     *
     * @since v1
     *
     * @example
     * import { LogicVector3SenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicVector3SenderComponent({ version: componentVersion });
     *
     * const identifier = component.identifier;
     * // `identifier` is `0`
     */
    identifier: number;
    /**
     * The output value of this `LogicVector3Sender` that a `LogicVector3Receiver` reads as its input.
     *
     * @since v1
     *
     * @example
     * import { LogicVector3SenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicVector3SenderComponent({ version: componentVersion });
     *
     * const value = component.value;
     * // `value` is `{ x: 0, y: 0, z: 0 }`
     */
    value: Vector3;
    /**
     * @see [Class: `LogicVector3SenderComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/LogicVector3SenderComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { LogicVector3SenderComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new LogicVector3SenderComponent({ version: componentVersion });
     */
    constructor({ version, updatedValue, changedExternally, identifier, value }: ComponentProps & LogicVector3SenderComponentProps);
    static fromBinary(reader: BinaryReader, version: number): LogicVector3SenderComponent;
    toBinary(version?: number): BinaryString;
}
export {};
