import type { BinaryReader } from '../BinaryReader.js';
import type { BinaryString } from '../types/BinaryString.js';
import { Component, type ComponentProps } from './Component.js';
type SlidingDoorComponentPropsV1 = {
    isOpen?: boolean | undefined;
};
export type SlidingDoorComponentProps = SlidingDoorComponentPropsV1;
/**
 * @see [Class: `SlidingDoorComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/SlidingDoorComponent.md)
 * @since v3.0.0
 * @version 1
 *
 * @example
 * import { SlidingDoorComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 1;
 * const component = new SlidingDoorComponent({ version: componentVersion });
 */
export declare class SlidingDoorComponent extends Component {
    /**
     * Reveals the open state of this component's prefab.
     *
     * @since v1
     *
     * @example
     * import { SlidingDoorComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new SlidingDoorComponent({ version: componentVersion });
     *
     * const isOpen = component.isOpen;
     * // `isOpen` is `false`
     */
    isOpen: boolean;
    /**
     * @see [Class: `SlidingDoorComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/SlidingDoorComponent.md)
     * @since v3.0.0
     * @version 1
     *
     * @example
     * import { SlidingDoorComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 1;
     * const component = new SlidingDoorComponent({ version: componentVersion });
     */
    constructor({ version, isOpen }: ComponentProps & SlidingDoorComponentProps);
    static fromBinary(reader: BinaryReader, version: number): SlidingDoorComponent;
    toBinary(version?: number): BinaryString;
}
export {};
