import type { BinaryReader } from '../BinaryReader.js';
import type { BinaryString } from '../types/BinaryString.js';
import { Component, type ComponentProps } from './Component.js';
type Stat = null | {
    hash: number;
    baseFlat: number;
};
type TimedModifier = null | {
    hash: number;
    value: number;
    isMultiplier: boolean;
    time: number;
};
type IndirectModifierSaveData = {
    valueOverDurationHash: number;
    baseValue: number;
    duration: number;
    tick: number;
};
type IndirectStatModifier = null | {
    hash: number;
    time: number;
    modifiers: IndirectModifierSaveData[];
};
type StatManagerComponentPropsV2 = {
    stats?: Stat[] | undefined;
    modifiers?: TimedModifier[] | undefined;
    indirectStatModifiers?: IndirectStatModifier[] | undefined;
};
export type StatManagerComponentProps = StatManagerComponentPropsV2;
/**
 * @see [Class: `StatManagerComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/StatManagerComponent.md)
 * @since v3.0.0
 * @version 2
 *
 * @example
 * import { StatManagerComponent } from 'att-string-transcoder';
 *
 * const componentVersion = 2;
 * const component = new StatManagerComponent({ version: componentVersion });
 */
export declare class StatManagerComponent extends Component {
    /**
     * @since v2
     *
     * @example
     * import { StatManagerComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new StatManagerComponent({ version: componentVersion });
     *
     * const stats = component.stats;
     * // `stats` is `[]`
     */
    stats: Stat[];
    /**
     * @since v2
     *
     * @example
     * import { StatManagerComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new StatManagerComponent({ version: componentVersion });
     *
     * const modifiers = component.modifiers;
     * // `modifiers` is `[]`
     */
    modifiers: TimedModifier[];
    /**
     * @since v2
     *
     * @example
     * import { StatManagerComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new StatManagerComponent({ version: componentVersion });
     *
     * const indirectStatModifiers = component.indirectStatModifiers;
     * // `indirectStatModifiers` is `[]`
     */
    indirectStatModifiers: IndirectStatModifier[];
    /**
     * @see [Class: `StatManagerComponent`](https://github.com/mdingena/att-string-transcoder/tree/main/docs/StatManagerComponent.md)
     * @since v3.0.0
     * @version 2
     *
     * @example
     * import { StatManagerComponent } from 'att-string-transcoder';
     *
     * const componentVersion = 2;
     * const component = new StatManagerComponent({ version: componentVersion });
     */
    constructor({ version, stats, modifiers, indirectStatModifiers }: ComponentProps & StatManagerComponentProps);
    static fromBinary(reader: BinaryReader, version: number): StatManagerComponent;
    toBinary(version?: number): BinaryString;
}
export {};
