import type { BinaryReader } from '../BinaryReader.js';
import type { PrefabComponents } from '../types/PrefabComponents.js';
/**
 * Reads all components from the given `BinaryReader` and returns a `PrefabComponents` object.
 *
 * @example
 * import { BinaryReader, readComponents } from 'att-string-transcoder';
 *
 * const reader = new BinaryReader('...');
 *
 * const versions = new Map<number, number>([
 *   [ComponentHash.NetworkRigidbody, 1],
 *   [ComponentHash.PhysicalMaterialPart, 1],
 *   [ComponentHash.Pickup, 2]
 *   // etc...
 * ]);
 *
 * const component = readComponents(reader, versions);
 */
export declare function readComponents(reader: BinaryReader, versions?: Map<number, number>): PrefabComponents;
