import type { BinaryReader } from '../BinaryReader.js';
import type { ATTPrefabName } from '../types/ATTPrefabName.js';
import type { PrefabEntities } from '../types/PrefabEntities.js';
/**
 * Reads all entities from the given `BinaryReader` and returns a `PrefabEntities` object.
 *
 * @example
 * import { BinaryReader, readEntities, type ATTPrefabName } from 'att-string-transcoder';
 *
 * const reader = new BinaryReader('...');
 * const prefabName = 'Handle_Short' as ATTPrefabName;
 *
 * const componentVersions = new Map<number, number>([
 *   [ComponentHash.NetworkRigidbody, 1],
 *   [ComponentHash.PhysicalMaterialPart, 1],
 *   [ComponentHash.Pickup, 2]
 *   // etc...
 * ]);
 *
 * const component = readEntities(reader, prefabName, componentVersions);
 */
export declare function readEntities<TPrefabName extends ATTPrefabName>(reader: BinaryReader, prefabName: TPrefabName, componentVersions?: Map<number, number>): PrefabEntities<TPrefabName>;
